@@ -8,7 +8,9 @@ from ._astropy_init import *   # noqa
 
 # top-level API as exposed to users
 from jdaviz.app import *  # noqa
-from jdaviz.configs.specviz import SpecViz  # noqa
+from jdaviz.configs.specviz import Specviz, SpecViz  # noqa
 from jdaviz.configs.specviz2d import Specviz2d  # noqa
-from jdaviz.configs.mosviz import MosViz  # noqa
-from jdaviz.configs.cubeviz import CubeViz  # noqa
+from jdaviz.configs.mosviz import Mosviz, MosViz  # noqa
+from jdaviz.configs.cubeviz import Cubeviz, CubeViz  # noqa
+from jdaviz.configs.imviz import Imviz  # noqa
+from jdaviz.utils import enable_hot_reloading  # noqa
