@@ -17,7 +17,7 @@ from jdaviz.core.events import (AddDataMessage,
                                 LineIdentifyMessage,
                                 SnackbarMessage,
                                 RedshiftMessage)
-from jdaviz.core.linelists import load_preset_linelist
+from jdaviz.core.linelists import load_preset_linelist, get_linelist_metadata
 from jdaviz.core.marks import SpectralLine
 from jdaviz.core.registries import tray_registry
 from jdaviz.core.template_mixin import PluginTemplateMixin
@@ -70,7 +70,9 @@ class LineListTool(PluginTemplateMixin):
         self.available_lists = self._viewer.available_linelists()
         self.list_to_load = None
         self.loaded_lists = ["Custom"]
-        self.list_contents = {"Custom": {"lines": [], "color": "#FF0000FF"}}
+        self.list_contents = {"Custom": {"lines": [],
+                                         "color": "#FF0000FF",
+                                         "medium": "Unknown (Custom)"}}
         self.line_mark_dict = {}
         self._units = {}
         self._bounds = {}
@@ -112,6 +114,14 @@ class LineListTool(PluginTemplateMixin):
         self._viewer.state.add_callback("x_max",
                                         lambda x_max: self._on_spectrum_viewer_limits_changed())
 
+        self._disable_if_no_data()
+
+    def _disable_if_no_data(self):
+        if len(self.app.data_collection) == 0:
+            self.disabled_msg = 'Line Lists unavailable when no data is loaded'
+        else:
+            self.disabled_msg = ''
+
     def _on_viewer_data_changed(self, msg=None):
         """
         Callback method for when data is added or removed from a viewer, or
@@ -129,6 +139,8 @@ class LineListTool(PluginTemplateMixin):
         msg : `glue.core.Message`
             The glue message passed to this callback method.
         """
+        self._disable_if_no_data()
+
         self._viewer_id = self.app._viewer_item_by_reference(
             'spectrum-viewer').get('id')
 
@@ -545,7 +557,10 @@ class LineListTool(PluginTemplateMixin):
         temp_table = self._viewer.load_line_list(temp_table, return_table=True,
                                                  show=False)
 
-        line_list_dict = {"lines": [], "color": "#FF000080"}
+        metadata = get_linelist_metadata()
+        list_medium = metadata[self.list_to_load].get('medium', 'Unknown').capitalize()
+
+        line_list_dict = {"lines": [], "color": "#FF000080", "medium": list_medium}
         # extra_fields = [x for x in temp_table.colnames if x not in
         #                ("linename", "rest", "name_rest")]
 
