@@ -3,6 +3,7 @@ import numpy as np
 from glue.core.subset import RoiSubsetState
 from glue_jupyter.bqplot.profile import BqplotProfileView
 from glue_jupyter.bqplot.image import BqplotImageView
+from glue_jupyter.bqplot.scatter.layer_artist import BqplotScatterLayerState
 from glue_jupyter.table import TableViewer
 
 from jdaviz.components.toolbar_nested import NestedJupyterToolbar
@@ -42,6 +43,7 @@ class JdavizViewerMixin:
     def _subscribe_to_layers_update(self):
         # subscribe to new layers
         self._expected_subset_layers = []
+        self._layers_with_defaults_applied = []
         self.state.add_callback('layers', self._on_layers_update)
 
     def _get_layer(self, label):
@@ -49,6 +51,17 @@ class JdavizViewerMixin:
             if layer.layer.label == label:
                 return layer
 
+    def _apply_layer_defaults(self, layer_state):
+        if hasattr(layer_state, 'as_steps'):
+            if layer_state.layer.label != layer_state.layer.data.label:
+                # then this is a subset, so default based on the parent data layer
+                layer_state.as_steps = self._get_layer(layer_state.layer.data.label).as_steps
+            else:
+                # default to not plotting with as_steps (despite glue defaulting to True)
+                layer_state.as_steps = False
+            # whenever as_steps changes, we need to redraw the uncertainties (if enabled)
+            layer_state.add_callback('as_steps', self._show_uncertainty_changed)
+
     def _expected_subset_layer_default(self, layer_state):
         if self.__class__.__name__ == 'CubevizImageView':
             # Do not override default for subsets as for some reason
@@ -62,6 +75,10 @@ class JdavizViewerMixin:
     def _update_layer_icons(self):
         # update visible_layers (TODO: move this somewhere that can update on color change, etc)
         def _get_layer_color(layer):
+            if isinstance(layer, BqplotScatterLayerState):
+                # then this could be a scatter layer in an image viewer,
+                # so we'll ignore the color_mode
+                return layer.color
             if getattr(self.state, 'color_mode', None) == 'Colormaps':
                 for subset in self.jdaviz_app.data_collection.subset_groups:
                     if subset.label == layer.layer.label:
@@ -71,12 +88,19 @@ class JdavizViewerMixin:
                 return ''
             return layer.color
 
+        def _get_layer_linewidth(layer):
+            linewidth = getattr(layer, 'linewidth', 0)
+            return min(linewidth, 6)
+
         def _get_layer_info(layer):
             if self.__class__.__name__ == 'CubevizProfileView' and len(layer.layer.data.shape) == 3:
                 suffix = f" (collapsed: {self.state.function})"
             else:
                 suffix = ""
 
+            if 'Trace' in layer.layer.data.meta:
+                return "mdi-chart-line-stacked", ""
+
             # then the underlying data is cube-like and we're in the profile viewer, so we
             # want to include the collapse function *unless* the layer is a spectral subset
             for subset in self.jdaviz_app.data_collection.subset_groups:
@@ -94,6 +118,7 @@ class JdavizViewerMixin:
             if layer.visible:
                 prefix_icon, suffix = _get_layer_info(layer)
                 visible_layers[layer.layer.label] = {'color': _get_layer_color(layer),
+                                                     'linewidth': _get_layer_linewidth(layer),
                                                      'prefix_icon': prefix_icon,
                                                      'suffix_label': suffix}
 
@@ -107,6 +132,8 @@ class JdavizViewerMixin:
             return
 
         viewer_item = self.jdaviz_app._viewer_item_by_id(self.reference_id)
+        if viewer_item is None:
+            return
         selected_data_items = viewer_item['selected_data_items']
 
         # update selected_data_items
@@ -127,12 +154,16 @@ class JdavizViewerMixin:
 
         self._update_layer_icons()
 
-        if not len(self._expected_subset_layers):
-            return
         # we'll make a deepcopy so that we can remove entries from the self._expected_subset_layers
         # to avoid recursion, but also handle multiple layers for the same subset
         expected_subset_layers = self._expected_subset_layers[:]
         for layer in self.state.layers:
+            layer_info = {'data_label': layer.layer.data.label,
+                          'layer_label': layer.layer.label}
+            if layer_info not in self._layers_with_defaults_applied:
+                self._layers_with_defaults_applied.append(layer_info)
+                self._apply_layer_defaults(layer)
+
             if layer.layer.label in expected_subset_layers:
                 if layer.layer.label in self._expected_subset_layers:
                     self._expected_subset_layers.remove(layer.layer.label)
